EncodedTextWriter

Struct EncodedTextWriter 

pub struct EncodedTextWriter<W> { /* private fields */ }
Text writer that encodes Unicode text with an explicit encoding.

Implementations

Source

impl<W> EncodedTextWriter<W>
where W: Write,

pub const fn new( inner: W, encoding: &'static Encoding, policy: CodingErrorPolicy, ) -> Self

Creates an encoded text writer.

Parameters
  • inner: Byte writer to receive encoded bytes.
  • encoding: Encoding used for outgoing text.
  • policy: Unencodable text handling policy.
Returns

A text writer using LF line endings.

pub const fn with_line_ending(self, line_ending: LineEnding) -> Self

Sets the line ending for this writer.

Parameters
  • line_ending: Line ending to use for subsequent lines.
Returns

This writer with the configured line ending.

pub const fn get_ref(&self) -> &W

Returns a shared reference to the wrapped byte writer.

Returns

The wrapped byte writer.

pub fn get_mut(&mut self) -> &mut W

Returns a mutable reference to the wrapped byte writer.

Returns

The wrapped byte writer.

pub fn into_inner(self) -> W

Returns the wrapped byte writer.

Returns

The underlying byte writer.