StrTextReader

Struct StrTextReader 

pub struct StrTextReader<'a> { /* private fields */ }
Text reader over a borrowed string slice.

Implementations

Source

impl<'a> StrTextReader<'a>

pub const fn new(text: &'a str) -> Self

Creates a reader over text.

Parameters
  • text: Borrowed text to read.
Returns

A reader positioned at the start of the text.

pub const fn position(&self) -> usize

Returns the current byte position in the underlying string slice.

Returns

The current byte position.